@@ -24,11 +24,12 @@ class lineWithFocusChart(NVD3Chart):
     Python example::
 
         from nvd3 import lineWithFocusChart
-        chart = lineWithFocusChart(name='lineWithFocusChart', date=True)
+        chart = lineWithFocusChart(name='lineWithFocusChart', date=True, x_axis_date_format="%d %b %Y")
         xdata = [1365026400000000, 1365026500000000, 1365026600000000]
         ydata = [-6, 5, -1]
 
-        extra_serie = {"tooltip": {"y_start": "", "y_end": " ext"}}
+        extra_serie = {"tooltip": {"y_start": "", "y_end": " ext"},
+                       "date_format": "%d %b %Y"}
         chart.add_serie(name="Serie 1", y=ydata, x=xdata, extra=extra_serie)
         chart.buildhtml()
 
@@ -76,12 +77,12 @@ class lineWithFocusChart(NVD3Chart):
             return chart;
         });
     """
-    def __init__(self, height=450, width=None, date=False, **kwargs):
+    def __init__(self, height=450, width=None, date=False, x_axis_date_format="%d %b %Y %H %S", **kwargs):
         NVD3Chart.__init__(self, **kwargs)
         if date:
             self.set_date_flag(True)
-            self.create_x_axis('xAxis', format='%d %b %Y', date=True)
-            self.create_x_axis('x2Axis', format='%d %b %Y', date=True)
+            self.create_x_axis('xAxis', format=x_axis_date_format, date=True)
+            self.create_x_axis('x2Axis', format=x_axis_date_format, date=True)
             self.set_custom_tooltip_flag(True)
         else:
             self.create_x_axis('xAxis', format=".2f")
